package go_handler_template

const ApiTestPipeline = `
kind: pipeline
type: docker
name: 部署test-api-{{ .Name }}

steps:
  - name: build
    image: plugins/docker
    volumes:
      - name: docker
        path: /var/run/docker.sock
    settings:
      username:
        from_secret: reg_username
      password:
        from_secret: reg_password
      repo: reg.icechen.cn/{{ .NameSpace }}/api-{{ .Name }}
      registry: reg.icechen.cn
      tags:
        - ${DRONE_COMMIT:0:8}
        - latest
      dockerfile: ./{{ .Root }}/Dockerfile
      purge: false

  - name: deploy
    image: bitsbeats/drone-helm3
    settings:
      kube_api_server:
        from_secret: kubernetes_server_test
      kube_token:
        from_secret: kubernetes_token_test
      kube_certificate:
        from_secret: kubernetes_cert_test
      chart: ./{{ .Root }}/deploy
      release: api-{{ .Name }}-test
      wait: true
      namespace: {{ .NameSpace }}
      values:
        - nameSpace={{ .NameSpace }}
        - aliasName={{ .AliasName }}
        - image=reg.icechen.cn/{{ .NameSpace }}/api-{{ .Name }}
        - imageTag=${DRONE_COMMIT:0:8}
        - port={{ .Port }}
{{ if .Host }}
        - host=t{{ .Host }}
{{ else }}
        - host=tapi.seamlesser.com
{{ end }}
{{ if .Path }}
        - path={{ .Path }}
{{ else }}
        - path=/{{ .NameSpace }}/{{ .Name }}/?(.*)
{{ end }}

volumes:
  - name: docker
    host:
      path: /var/run/docker.sock
`
